@@ -1,7 +1,7 @@
 /*
  * autocutsel.c by Michael Witrant <mike @ lepton . fr>
  * Synchronizes the cutbuffer and the selection
- * version 0.6.1
+ * version 0.6.2
  * Copyright (c) 2001,2002 Michael Witrant.
  * 
  * Most code taken from:
@@ -79,7 +79,8 @@ static XrmOptionDescRec optionDesc[] = {
 int Syntax(call)
      char *call;
 {
-  fprintf (stderr, "usage:  %s [-selection <name>] [-cutbuffer <number>] [-pause <milliseconds>] [-debug] [-verbose]\n", 
+  fprintf (stderr,
+	   "usage:  %s [-selection <name>] [-cutbuffer <number>] [-pause <milliseconds>] [-debug] [-verbose]\n", 
 	   call);
   exit (1);
 }
@@ -172,9 +173,6 @@ static Boolean ConvertSelection(w, selection, target,
   XSelectionRequestEvent* req =
     XtGetSelectionRequest(w, *selection, (XtRequestId)NULL);
    
-  if (options.debug)
-    printf("%p requested the selection\n", target);
-   
   if (*target == XA_TARGETS(d)) {
     Atom* targetP;
     Atom* std_targets;
@@ -207,7 +205,7 @@ static Boolean ConvertSelection(w, selection, target,
 
     if (options.debug)
       {
-	printf("Giving value as string: ");
+	printf("Giving selection as string: ");
 	PrintValue((char*)*value, *length);
 	printf("\n");
       }
@@ -221,6 +219,10 @@ static Boolean ConvertSelection(w, selection, target,
     *type = XA_INTEGER;
     *length = 1;
     *format = 32;
+
+    if (options.debug)
+      printf("Giving selection list length: %d\n", *temp);
+
     return True;
   }
   if (*target == XA_LENGTH(d)) {
@@ -230,6 +232,10 @@ static Boolean ConvertSelection(w, selection, target,
     *type = XA_INTEGER;
     *length = 1;
     *format = 32;
+
+    if (options.debug)
+      printf("Giving selection length: %d\n", *temp);
+
     return True;
   }
 #ifdef notdef
@@ -249,6 +255,9 @@ static Boolean ConvertSelection(w, selection, target,
     return True;
    
   /* else */
+  if (options.debug)
+    printf("Unable to convert selection\n");
+
   return False;
 }
 
@@ -322,7 +331,7 @@ static void OwnSelectionIfDiffers(w, client_data, selection, type, value, receiv
       if (options.verbose)
 	{
 	  printf("cut -> sel: ");
-	  PrintValue(value, length);
+	  PrintValue(options.value, options.length);
 	  printf("\n");
 	}
       
